OverwriteFormat

Enum OverwriteFormat 

pub enum OverwriteFormat {
    NoOverwrite,
    OverwriteToCompact,
    OverwriteToPadded,
    // some variants omitted
}
The list of configuration options.

Variants



NoOverwrite

Instructs Blobfs to always respond false to fuchsia.fxfs.BlobCreator.NeedsOverwrite. Blobs written will use the the default format in the filesystem superblock. Note that this does not prevent a caller from overwriting a blob.



OverwriteToCompact

Instructs Blobfs to respond true to fuchsia.fxfs.BlobCreator.NeedsOverwrite for existing blobs not in compact format, and all blobs written will be written in compact format.



OverwriteToPadded

Instructs Blobfs to respond true to fuchsia.fxfs.BlobCreator.NeedsOverwrite for existing blobs not in padded format, and all blobs written will be written in padded format.

Implementations

Source

impl OverwriteFormat

pub fn from_primitive(prim: u32) -> Option<Self>

pub fn from_primitive_allow_unknown(prim: u32) -> Self

pub fn unknown() -> Self

pub const fn into_primitive(self) -> u32

pub fn is_unknown(&self) -> bool