pub struct OverwriteConfigurationSetRequest {
pub overwrite_format: OverwriteFormat,
}Fields
overwrite_format: OverwriteFormatTrait Implementations
Sourceimpl Clone for OverwriteConfigurationSetRequest
impl Clone for OverwriteConfigurationSetRequest
Sourcefn clone(&self) -> OverwriteConfigurationSetRequest
fn clone(&self) -> OverwriteConfigurationSetRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<OverwriteConfigurationSetRequest, D> for OverwriteConfigurationSetRequest
impl<D: ResourceDialect> Decode<OverwriteConfigurationSetRequest, D> for OverwriteConfigurationSetRequest
Sourceimpl<D: ResourceDialect> Encode<OverwriteConfigurationSetRequest, D> for &OverwriteConfigurationSetRequest
impl<D: ResourceDialect> Encode<OverwriteConfigurationSetRequest, D> for &OverwriteConfigurationSetRequest
Sourceimpl<D: ResourceDialect, T0: Encode<OverwriteFormat, D>> Encode<OverwriteConfigurationSetRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<OverwriteFormat, D>> Encode<OverwriteConfigurationSetRequest, D> for (T0,)
Sourceimpl Ord for OverwriteConfigurationSetRequest
impl Ord for OverwriteConfigurationSetRequest
Sourcefn cmp(&self, other: &OverwriteConfigurationSetRequest) -> Ordering
fn cmp(&self, other: &OverwriteConfigurationSetRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OverwriteConfigurationSetRequest
impl PartialEq for OverwriteConfigurationSetRequest
Sourcefn eq(&self, other: &OverwriteConfigurationSetRequest) -> bool
fn eq(&self, other: &OverwriteConfigurationSetRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OverwriteConfigurationSetRequest
impl PartialOrd for OverwriteConfigurationSetRequest
Sourceimpl TypeMarker for OverwriteConfigurationSetRequest
impl TypeMarker for OverwriteConfigurationSetRequest
Sourcetype Owned = OverwriteConfigurationSetRequest
type Owned = OverwriteConfigurationSetRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for OverwriteConfigurationSetRequest
impl ValueTypeMarker for OverwriteConfigurationSetRequest
Sourcetype Borrowed<'a> = &'a OverwriteConfigurationSetRequest
type Borrowed<'a> = &'a OverwriteConfigurationSetRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for OverwriteConfigurationSetRequest
impl Eq for OverwriteConfigurationSetRequest
impl Persistable for OverwriteConfigurationSetRequest
impl StructuralPartialEq for OverwriteConfigurationSetRequest